@@ -46,12 +46,15 @@ let list = [
   "Artistic-1.0-Perl";
   "Artistic-1.0-cl8";
   "Artistic-2.0";
+  "Artistic-dist";
+  "Aspell-RU";
   "BSD-1-Clause";
   "BSD-2-Clause";
   "BSD-2-Clause-Darwin";
   "BSD-2-Clause-Patent";
   "BSD-2-Clause-Views";
   "BSD-2-Clause-first-lines";
+  "BSD-2-Clause-pkgconf-disclaimer";
   "BSD-3-Clause";
   "BSD-3-Clause-Attribution";
   "BSD-3-Clause-Clear";
@@ -192,6 +195,7 @@ let list = [
   "Cornell-Lossless-JPEG";
   "Cronyx";
   "Crossword";
+  "CryptoSwift";
   "CrystalStacker";
   "Cube";
   "D-FSL-1.0";
@@ -202,6 +206,7 @@ let list = [
   "DRL-1.0";
   "DRL-1.1";
   "DSDP";
+  "DocBook-DTD";
   "DocBook-Schema";
   "DocBook-Stylesheet";
   "DocBook-XML";
@@ -227,7 +232,10 @@ let list = [
   "FSFAP-no-warranty-disclaimer";
   "FSFUL";
   "FSFULLR";
+  "FSFULLRSD";
   "FSFULLRWD";
+  "FSL-1.1-ALv2";
+  "FSL-1.1-MIT";
   "FTL";
   "Fair";
   "Ferguson-Twofish";
@@ -263,11 +271,13 @@ let list = [
   "GPL-2.0-or-later";
   "GPL-3.0-only";
   "GPL-3.0-or-later";
+  "Game-Programming-Gems";
   "Giftware";
   "Glide";
   "Glulxe";
   "Graphics-Gems";
   "Gutmann";
+  "HDF5";
   "HIDAPI";
   "HP-1986";
   "HP-1989";
@@ -413,6 +423,7 @@ let list = [
   "NPL-1.1";
   "NPOSL-3.0";
   "NRL";
+  "NTIA-PD";
   "NTP";
   "NTP-0";
   "Naumen";
@@ -515,11 +526,13 @@ let list = [
   "SMLNJ";
   "SMPPL";
   "SNIA";
+  "SOFA";
   "SPL-1.0";
   "SSH-OpenSSH";
   "SSH-short";
   "SSLeay-standalone";
   "SSPL-1.0";
+  "SUL-1.0";
   "SWL";
   "Saxpath";
   "SchemeReport";
@@ -565,6 +578,8 @@ let list = [
   "Unicode-TOU";
   "UnixCrypt";
   "Unlicense";
+  "Unlicense-libtelnet";
+  "Unlicense-libwhirlpool";
   "VOSTROM";
   "VSL-1.0";
   "Vim";
@@ -618,6 +633,8 @@ let list = [
   "gtkbook";
   "hdparm";
   "iMatix";
+  "jove";
+  "libpng-1.6.35";
   "libpng-2.0";
   "libselinux-1.0";
   "libtiff";
@@ -625,10 +642,12 @@ let list = [
   "lsof";
   "magaz";
   "mailprio";
+  "man2html";
   "metamail";
   "mpi-permissive";
   "mpich2";
   "mplus";
+  "ngrep";
   "pkgconf";
   "pnmstitch";
   "psfrag";
